# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['canvasrobot', 'canvasrobot.entities']

package_data = \
{'': ['*']}

install_requires = \
['canvasapi>=3.0.0,<3.1.0',
 'keyring',
 'openpyxl>=3.0.10,<4.0.0',
 'pyaml>=21.10.1,<22.0.0',
 'pydal>=20220814.1,<20220815.0',
 'requests>=2.28.1,<2.29.0',
 'rich>=12.5.1,<13.0.0',
 'toml']

setup_kwargs = {
    'name': 'canvasrobot',
    'version': '0.1.3',
    'description': '',
    'long_description': 'None',
    'author': 'Nico de Groot',
    'author_email': 'ndegroot0@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
